==> xtel-3.0.7-2.tar.gz: xtel-3.0.7/globald.h <==
/*	
 *   xtel - Emulateur MINITEL sous X11
 *
 *   Copyright (C) 1991-1994  Lectra Systemes & Pierre Ficheux
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ident "$Id: globald.h,v 1.4 1995/07/24 13:42:40 pierre Exp $"

#ifndef _globald_h
#define _globald_h

typedef char Boolean;
#define True	1
#define False	0

#ifndef EXTERN
#define EXTERN extern
#endif

/*
 * Variables
 */
#ifndef __FreeBSD__
extern char *sys_errlist[];
#endif

EXTERN struct definition_ligne definition_lignes[MAX_LIGNES]; 
EXTERN struct definition_service definition_services[MAX_SERVICES];
EXTERN Boolean flag_m1;
EXTERN int fd_modem;
EXTERN int nb_lignes;
EXTERN char numero_ligne;
#ifndef USE_SYSLOG
EXTERN FILE *fp_console;
#endif

/*
 * Fonctions
 */
#ifdef __STDC__

/* xteld.c */
void demande_fin_fils(void);
void erreur_a_xtel(char *s, int code_erreur);
int service_autorise(int indice_service);
void deconnexion(void);
void appel_service(char *service_teletel);
int main(int ac, char **av);
/* dial.c */
void myundial(int fd);
int mydial(char *telno, char *device);
/* config.c */
int lecture_services(void);
int lecture_configuration_lignes(void);

#else

void demande_fin_fils();
void erreur_a_xtel();
int service_autorise();
void deconnexion();
void appel_service();
int main();
void myundial();
int mydial();
int lecture_services();
int lecture_configuration_lignes();

#endif /* __STDC__ */

#endif

==> xtel_3.1.1.orig.tar.gz: xtel-3.1.1.orig/globald.h <==
/*	
 *   xtel - Emulateur MINITEL sous X11
 *
 *   Copyright (C) 1991-1996  Lectra Systemes & Pierre Ficheux
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ident "$Id: globald.h,v 1.5 1996/09/22 21:10:26 pierre Exp $"

#ifndef _globald_h
#define _globald_h

typedef char Boolean;
#define True	1
#define False	0

#ifndef EXTERN
#define EXTERN extern
#endif

/*
 * Variables
 */
#ifndef __FreeBSD__
extern char *sys_errlist[];
#endif

EXTERN struct definition_ligne definition_lignes[MAX_LIGNES]; 
EXTERN struct definition_service definition_services[MAX_SERVICES];
EXTERN Boolean flag_m1;
EXTERN int fd_modem;
EXTERN int nb_lignes;
EXTERN char numero_ligne;
#ifndef USE_SYSLOG
EXTERN FILE *fp_console;
#endif

/*
 * Fonctions
 */
#ifdef __STDC__

/* xteld.c */
void demande_fin_fils(void);
void erreur_a_xtel(char *s, int code_erreur);
int service_autorise(int indice_service);
void deconnexion(void);
void appel_service(char *service_teletel);
int main(int ac, char **av);
/* dial.c */
void myundial(int fd);
int mydial(char *telno, char *device);
/* config.c */
int lecture_services(void);
int lecture_configuration_lignes(void);
/* misc.c */
char *next_token(char *, char *);
char *build_name(char *);

#else

void demande_fin_fils();
void erreur_a_xtel();
int service_autorise();
void deconnexion();
void appel_service();
int main();
void myundial();
int mydial();
int lecture_services();
int lecture_configuration_lignes();
char *next_token();
char *build_name();

#endif /* __STDC__ */

#endif
